@@ -1,22 +1,31 @@
 /* asn1.c --- Wrapper around pseudo-ASN.1 token format.
- * Copyright (C) 2003-2014 Simon Josefsson
+ * Copyright (C) 2003-2022 Simon Josefsson
  *
- * This file is part of the Generic Security Service (GSS).
+ * This file is part of the GNU Generic Security Service Library.
  *
- * GSS is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ * This file is free software: you can redistribute it and/or modify
+ * it under the terms of either:
  *
- * GSS is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
- * License for more details.
+ *  * the GNU Lesser General Public License as published by the Free
+ *    Software Foundation; either version 3 of the License, or (at
+ *    your option) any later version.
  *
- * You should have received a copy of the GNU General Public License
- * along with GSS; if not, see http://www.gnu.org/licenses or write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth
- * Floor, Boston, MA 02110-1301, USA.
+ * or
+ *
+ * * the GNU General Public License as published by the Free Software
+ *   Foundation; either version 2 of the License, or (at your option)
+ *   any later version.
+ *
+ * or both in parallel, as here.
+ *
+ * This file is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received copies of the GNU General Public License
+ * and the GNU Lesser General Public License along with this file.  If
+ * not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -27,7 +36,7 @@
  * Copyright (C) 2002 Fabio Fiorina.
  */
 static void
-_gss_asn1_length_der (size_t len, unsigned char *ans, size_t * ans_len)
+_gss_asn1_length_der (size_t len, unsigned char *ans, size_t *ans_len)
 {
   size_t k;
   unsigned char temp[sizeof (len)];
@@ -60,7 +69,7 @@ _gss_asn1_length_der (size_t len, unsigned char *ans, size_t * ans_len)
 }
 
 static size_t
-_gss_asn1_get_length_der (const char *der, size_t der_len, size_t * len)
+_gss_asn1_get_length_der (const char *der, size_t der_len, size_t *len)
 {
   size_t ans;
   size_t k, punt;
@@ -107,7 +116,7 @@ OM_uint32
 _gss_encapsulate_token_prefix (const char *prefix, size_t prefixlen,
 			       const char *in, size_t inlen,
 			       const char *oid, OM_uint32 oidlen,
-			       void **out, size_t * outlen)
+			       void **out, size_t *outlen)
 {
   size_t oidlenlen;
   size_t asn1len, asn1lenlen;
@@ -167,8 +176,7 @@ _gss_encapsulate_token_prefix (const char *prefix, size_t prefixlen,
  **/
 extern OM_uint32
 gss_encapsulate_token (gss_const_buffer_t input_token,
-		       gss_const_OID token_oid,
-		       gss_buffer_t output_token)
+		       gss_const_OID token_oid, gss_buffer_t output_token)
 {
   int rc;
 
@@ -194,8 +202,8 @@ gss_encapsulate_token (gss_const_buffer_t input_token,
 
 int
 _gss_decapsulate_token (const char *in, size_t inlen,
-			char **oid, size_t * oidlen,
-			char **out, size_t * outlen)
+			char **oid, size_t *oidlen,
+			char **out, size_t *outlen)
 {
   size_t i;
   size_t asn1lenlen;
@@ -272,8 +280,7 @@ _gss_decapsulate_token (const char *in, size_t inlen,
  **/
 OM_uint32
 gss_decapsulate_token (gss_const_buffer_t input_token,
-		       gss_const_OID token_oid,
-		       gss_buffer_t output_token)
+		       gss_const_OID token_oid, gss_buffer_t output_token)
 {
   gss_OID_desc tmpoid;
   char *oid = NULL, *out = NULL;
