@@ -1,22 +1,31 @@
 /* cred.c --- Implementation of GSS-API Credential Management functions.
- * Copyright (C) 2003-2014 Simon Josefsson
+ * Copyright (C) 2003-2022 Simon Josefsson
  *
- * This file is part of the Generic Security Service (GSS).
+ * This file is part of the GNU Generic Security Service Library.
  *
- * GSS is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ * This file is free software: you can redistribute it and/or modify
+ * it under the terms of either:
  *
- * GSS is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
- * License for more details.
+ *  * the GNU Lesser General Public License as published by the Free
+ *    Software Foundation; either version 3 of the License, or (at
+ *    your option) any later version.
  *
- * You should have received a copy of the GNU General Public License
- * along with GSS; if not, see http://www.gnu.org/licenses or write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth
- * Floor, Boston, MA 02110-1301, USA.
+ * or
+ *
+ * * the GNU General Public License as published by the Free Software
+ *   Foundation; either version 2 of the License, or (at your option)
+ *   any later version.
+ *
+ * or both in parallel, as here.
+ *
+ * This file is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received copies of the GNU General Public License
+ * and the GNU Lesser General Public License along with this file.  If
+ * not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -391,6 +400,13 @@ gss_inquire_cred (OM_uint32 * minor_status,
 	return maj_stat;
     }
 
+  if (!credh)
+    {
+      if (minor_status)
+	*minor_status = 0;
+      return GSS_S_NO_CRED;
+    }
+
   mech = _gss_find_mech (credh->mech);
   if (mech == NULL)
     {
