@@ -1,22 +1,20 @@
 /* gss.c --- Command line tool for GSS.
- * Copyright (C) 2004-2014 Simon Josefsson
+ * Copyright (C) 2004-2022 Simon Josefsson
  *
- * This file is part of the Generic Security Service (GSS).
+ * This file is part of the GNU Generic Security Service Library.
  *
- * GSS is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ * This file is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published
+ * by the Free Software Foundation, either version 3 of the License,
+ * or (at your option) any later version.
  *
- * GSS is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
- * License for more details.
+ * This file is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GSS; if not, see http://www.gnu.org/licenses or write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth
- * Floor, Boston, MA 02110-1301, USA.
+ * along with this file.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -109,7 +107,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
 }
 
 static int
-describe_major (unsigned int quiet, long major)
+describe_major (unsigned int quiet, OM_uint32 major)
 {
   gss_buffer_desc status_string;
   OM_uint32 message_context = 0;
@@ -119,7 +117,7 @@ describe_major (unsigned int quiet, long major)
 
   if (!quiet)
     {
-      printf (_("GSS-API major status code %ld (0x%lx).\n\n"), major, major);
+      printf (_("GSS-API major status code %u (0x%x).\n\n"), major, major);
 
       printf (_("   MSB                               "
 		"                                  LSB\n"
@@ -128,13 +126,13 @@ describe_major (unsigned int quiet, long major)
 		"   |  Calling Error  |  Routine Error"
 		"  |       Supplementary Info        |\n   | "));
       for (i = 0; i < 8; i++)
-	printf ("%ld ", (major >> (31 - i)) & 1);
+	printf ("%c ", ((major >> (31 - i)) & 1) ? '1' : '0');
       printf ("| ");
       for (i = 0; i < 8; i++)
-	printf ("%ld ", (major >> (23 - i)) & 1);
+	printf ("%c ", ((major >> (23 - i)) & 1) ? '1' : '0');
       printf ("| ");
       for (i = 0; i < 16; i++)
-	printf ("%ld ", (major >> (15 - i)) & 1);
+	printf ("%c ", ((major >> (15 - i)) & 1) ? '1' : '0');
       printf (_("|\n"
 		"   +-----------------+---------------"
 		"--+---------------------------------+\n"
@@ -145,8 +143,8 @@ describe_major (unsigned int quiet, long major)
   if (GSS_ROUTINE_ERROR (major))
     {
       if (!quiet)
-	printf (_("Masked routine error %ld (0x%lx) shifted "
-		  "into %ld (0x%lx):\n"),
+	printf (_("Masked routine error %lu (0x%lx) shifted "
+		  "into %lu (0x%lx):\n"),
 		GSS_ROUTINE_ERROR (major),
 		GSS_ROUTINE_ERROR (major),
 		GSS_ROUTINE_ERROR (major) >>
@@ -161,7 +159,8 @@ describe_major (unsigned int quiet, long major)
 				    &message_context, &status_string);
 	  if (GSS_ERROR (maj))
 	    {
-	      error (0, 0, _("displaying status code failed (%d)"), maj);
+	      error (0, 0, _("displaying status code failed (%u/%u)"), maj,
+		     min);
 	      rc = 1;
 	      break;
 	    }
@@ -181,7 +180,7 @@ describe_major (unsigned int quiet, long major)
     {
       if (!quiet)
 	printf
-	  (_("Masked calling error %ld (0x%lx) shifted into %ld (0x%lx):\n"),
+	  (_("Masked calling error %lu (0x%lx) shifted into %lu (0x%lx):\n"),
 	   GSS_CALLING_ERROR (major),
 	   GSS_CALLING_ERROR (major),
 	   GSS_CALLING_ERROR (major) >> GSS_C_CALLING_ERROR_OFFSET,
@@ -195,7 +194,8 @@ describe_major (unsigned int quiet, long major)
 				    &message_context, &status_string);
 	  if (GSS_ERROR (maj))
 	    {
-	      error (0, 0, _("displaying status code failed (%d)"), maj);
+	      error (0, 0, _("displaying status code failed (%u/%u)"),
+		     maj, min);
 	      rc = 1;
 	      break;
 	    }
@@ -214,8 +214,8 @@ describe_major (unsigned int quiet, long major)
   if (GSS_SUPPLEMENTARY_INFO (major))
     {
       if (!quiet)
-	printf (_("Masked supplementary info %ld (0x%lx) shifted "
-		  "into %ld (0x%lx):\n"),
+	printf (_("Masked supplementary info %lu (0x%lx) shifted "
+		  "into %lu (0x%lx):\n"),
 		GSS_SUPPLEMENTARY_INFO (major),
 		GSS_SUPPLEMENTARY_INFO (major),
 		GSS_SUPPLEMENTARY_INFO (major) >>
@@ -231,7 +231,8 @@ describe_major (unsigned int quiet, long major)
 				    &message_context, &status_string);
 	  if (GSS_ERROR (maj))
 	    {
-	      error (0, 0, _("displaying status code failed (%d)"), maj);
+	      error (0, 0, _("displaying status code failed (%u/%u)"), maj,
+		     min);
 	      rc = 1;
 	      break;
 	    }
@@ -266,7 +267,7 @@ list_mechanisms (unsigned quiet)
   maj = gss_indicate_mechs (&min, &mech_set);
   if (GSS_ERROR (maj))
     {
-      error (0, 0, _("indicating mechanisms failed (%d)"), maj);
+      error (0, 0, _("indicating mechanisms failed (%u/%u)"), maj, min);
       return 1;
     }
 
@@ -282,8 +283,9 @@ list_mechanisms (unsigned quiet)
 					   &mech_description);
       if (GSS_ERROR (maj))
 	{
-	  error (0, 0, _("inquiring information about mechanism failed (%d)"),
-		 maj);
+	  error (0, 0,
+		 _("inquiring information about mechanism failed (%u/%u)"),
+		 maj, min);
 	  continue;
 	}
 
@@ -299,7 +301,7 @@ list_mechanisms (unsigned quiet)
 }
 
 static ssize_t
-gettrimline (char **line, size_t * n, FILE * fh)
+gettrimline (char **line, size_t *n, FILE * fh)
 {
   ssize_t s = getline (line, n, fh);
 
@@ -325,7 +327,7 @@ init_sec_context (unsigned quiet, const char *mech, const char *server)
   gss_buffer_desc bufdesc;
   gss_buffer_desc sasl_mech_name;
   gss_OID mech_type;
-  size_t outlen;
+  idx_t outlen;
   char *out;
   ssize_t s;
   char *line = NULL;
@@ -339,7 +341,7 @@ init_sec_context (unsigned quiet, const char *mech, const char *server)
   maj = gss_inquire_mech_for_saslname (&min, &sasl_mech_name, &mech_type);
   if (GSS_ERROR (maj))
     error (EXIT_FAILURE, 0,
-	   _("inquiring mechanism for SASL name (%d/%d)"), maj, min);
+	   _("inquiring mechanism for SASL name (%u/%u)"), maj, min);
 
   if (server)
     {
@@ -352,7 +354,7 @@ init_sec_context (unsigned quiet, const char *mech, const char *server)
 			     &servername);
       if (GSS_ERROR (maj))
 	error (EXIT_FAILURE, 0,
-	       _("could not import server name \"%s\" (%d/%d)"),
+	       _("could not import server name \"%s\" (%u/%u)"),
 	       server, maj, min);
     }
 
@@ -371,7 +373,7 @@ init_sec_context (unsigned quiet, const char *mech, const char *server)
 				  inbuf, NULL, &bufdesc, &ret_flags, NULL);
       if (GSS_ERROR (maj))
 	error (EXIT_FAILURE, 0,
-	       _("initializing security context failed (%d/%d)"), maj, min);
+	       _("initializing security context failed (%u/%u)"), maj, min);
 
       outlen = base64_encode_alloc (bufdesc.value, bufdesc.length, &out);
       if (out == NULL && outlen == 0 && bufdesc.length != 0)
@@ -433,7 +435,7 @@ accept_sec_context (unsigned quiet, const char *mech, const char *server)
   gss_buffer_desc bufdesc, bufdesc2;
   gss_OID mech_type = GSS_C_NO_OID;
   char *out;
-  size_t outlen;
+  idx_t outlen;
   ssize_t s;
   char *line = NULL;
   size_t n = 0;
@@ -441,26 +443,26 @@ accept_sec_context (unsigned quiet, const char *mech, const char *server)
   OM_uint32 ret_flags;
 
   /*
-    We support these variants:
+     We support these variants:
 
-    1) No call to gss_acquire_cred at all.  This happens if mech=NULL
-    and server=NULL.
+     1) No call to gss_acquire_cred at all.  This happens if mech=NULL
+     and server=NULL.
 
-    2) Call to gss_acquire_cred with desired_mechs=GSS_C_NULL_OID_SET
-    and desired_name=GSS_C_NO_NAME.  This happens if mech="*" (the
-    string) and server=NULL.
+     2) Call to gss_acquire_cred with desired_mechs=GSS_C_NULL_OID_SET
+     and desired_name=GSS_C_NO_NAME.  This happens if mech="*" (the
+     string) and server=NULL.
 
-    3) Call to gss_acquire_cred with desired_mechs=GSS_C_NULL_OID_SET
-    and desired_name=server.  This happens if mech=NULL or mech="*"
-    (the string) and server!=NULL.
+     3) Call to gss_acquire_cred with desired_mechs=GSS_C_NULL_OID_SET
+     and desired_name=server.  This happens if mech=NULL or mech="*"
+     (the string) and server!=NULL.
 
-    4) Call to gss_acquire_cred with desired_mechs=mech and
-    desired_name=GSS_C_NO_NAME.  This happens if mech is a valid
-    SASL-name and server=NULL.
+     4) Call to gss_acquire_cred with desired_mechs=mech and
+     desired_name=GSS_C_NO_NAME.  This happens if mech is a valid
+     SASL-name and server=NULL.
 
-    5) Call to gss_acquire_cred with desired_mechs=mech and
-    desired_name=server.  This happens if mech is a valid SASL-name
-    and server!=NULL.
+     5) Call to gss_acquire_cred with desired_mechs=mech and
+     desired_name=server.  This happens if mech is a valid SASL-name
+     and server!=NULL.
    */
 
   if (mech || server)
@@ -480,7 +482,7 @@ accept_sec_context (unsigned quiet, const char *mech, const char *server)
 					       &mech_type);
 	  if (GSS_ERROR (maj))
 	    error (EXIT_FAILURE, 0,
-		   _("inquiring mechanism for SASL name (%d/%d)"), maj, min);
+		   _("inquiring mechanism for SASL name (%u/%u)"), maj, min);
 	}
 
       if (server)
@@ -495,7 +497,7 @@ accept_sec_context (unsigned quiet, const char *mech, const char *server)
 				 &servername);
 	  if (GSS_ERROR (maj))
 	    error (EXIT_FAILURE, 0,
-		   _("could not import server name \"%s\" (%d/%d)"),
+		   _("could not import server name \"%s\" (%u/%u)"),
 		   server, maj, min);
 	}
 
@@ -503,13 +505,13 @@ accept_sec_context (unsigned quiet, const char *mech, const char *server)
 	{
 	  maj = gss_create_empty_oid_set (&min, &mech_types);
 	  if (GSS_ERROR (maj))
-	    error (EXIT_FAILURE, 0, "gss_create_empty_oid_set (%d/%d)",
+	    error (EXIT_FAILURE, 0, "gss_create_empty_oid_set (%u/%u)",
 		   maj, min);
 
 	  maj = gss_add_oid_set_member (&min, mech_type, &mech_types);
 	  if (GSS_ERROR (maj))
-	    error (EXIT_FAILURE, 0, "gss_add_oid_set_member (%d/%d)",
-		   maj, min);
+	    error (EXIT_FAILURE, 0, "gss_add_oid_set_member (%u/%u)", maj,
+		   min);
 	}
 
       printf ("Acquiring credentials...\n");
@@ -517,13 +519,13 @@ accept_sec_context (unsigned quiet, const char *mech, const char *server)
 			      &cred, NULL, NULL);
       if (GSS_ERROR (maj))
 	error (EXIT_FAILURE, 0,
-	       _("could not acquire server credentials (%d/%d)"), maj, min);
+	       _("could not acquire server credentials (%u/%u)"), maj, min);
 
       if (mech_type != GSS_C_NO_OID)
 	{
 	  maj = gss_release_oid_set (&min, &mech_types);
 	  if (GSS_ERROR (maj))
-	    error (EXIT_FAILURE, 0, "gss_release_oid_set (%d/%d)", maj, min);
+	    error (EXIT_FAILURE, 0, "gss_release_oid_set (%u/%u)", maj, min);
 	}
     }
 
@@ -557,7 +559,7 @@ accept_sec_context (unsigned quiet, const char *mech, const char *server)
 				    &bufdesc2, &ret_flags, NULL, NULL);
       if (GSS_ERROR (maj))
 	error (EXIT_FAILURE, 0,
-	       _("accepting security context failed (%d/%d)"), maj, min);
+	       _("accepting security context failed (%u/%u)"), maj, min);
 
       outlen = base64_encode_alloc (bufdesc2.value, bufdesc2.length, &out);
       if (out == NULL && outlen == 0 && bufdesc2.length != 0)
