@@ -1,22 +1,20 @@
 /* basic.c --- Basic GSS self tests.
- * Copyright (C) 2003-2014 Simon Josefsson
+ * Copyright (C) 2003-2022 Simon Josefsson
  *
- * This file is part of the Generic Security Service (GSS).
+ * This file is part of the GNU Generic Security Service Library.
  *
- * GSS is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ * This file is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published
+ * by the Free Software Foundation, either version 3 of the License,
+ * or (at your option) any later version.
  *
- * GSS is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
- * License for more details.
+ * This file is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GSS; if not, see http://www.gnu.org/licenses or write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth
- * Floor, Boston, MA 02110-1301, USA.
+ * along with this file.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -65,7 +63,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_create_empty_oid_set() OK\n");
   else
-    fail ("gss_create_empty_oid_set() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_create_empty_oid_set() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Test empty set */
   maj_stat = gss_test_oid_set_member (&min_stat, GSS_C_NT_USER_NAME,
@@ -73,7 +71,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    OID present in empty set => %d\n", n);
@@ -81,14 +79,14 @@ main (int argc, char *argv[])
   if (!n)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Add an OID */
   maj_stat = gss_add_oid_set_member (&min_stat, GSS_C_NT_USER_NAME, &oids);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_add_oid_set_member() OK\n");
   else
-    fail ("gss_add_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_add_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Test set for added OID */
   maj_stat = gss_test_oid_set_member (&min_stat, GSS_C_NT_USER_NAME,
@@ -96,7 +94,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    OID present in set with the OID added to it => %d\n", n);
@@ -104,7 +102,7 @@ main (int argc, char *argv[])
   if (n)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Test set for another OID */
   maj_stat = gss_test_oid_set_member (&min_stat, GSS_C_NT_ANONYMOUS,
@@ -112,7 +110,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    Another OID present in set without the OID => %d\n", n);
@@ -120,14 +118,14 @@ main (int argc, char *argv[])
   if (!n)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Add another OID */
   maj_stat = gss_add_oid_set_member (&min_stat, GSS_C_NT_ANONYMOUS, &oids);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_add_oid_set_member() OK\n");
   else
-    fail ("gss_add_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_add_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Test set for added OID */
   maj_stat = gss_test_oid_set_member (&min_stat, GSS_C_NT_ANONYMOUS,
@@ -135,7 +133,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    Another OID present in set with it added => %d\n", n);
@@ -143,7 +141,7 @@ main (int argc, char *argv[])
   if (n)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Test set for first OID */
   maj_stat = gss_test_oid_set_member (&min_stat, GSS_C_NT_USER_NAME,
@@ -151,7 +149,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    First OID present in set => %d\n", n);
@@ -159,13 +157,13 @@ main (int argc, char *argv[])
   if (n)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   maj_stat = gss_release_oid_set (&min_stat, &oids);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_release_oid_set() OK\n");
   else
-    fail ("gss_release_oid_set() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_release_oid_set() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Check mechs */
   oids = GSS_C_NO_OID_SET;
@@ -173,14 +171,14 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_indicate_mechs() OK\n");
   else
-    fail ("gss_indicate_mechs() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_indicate_mechs() failed (%u,%u)\n", maj_stat, min_stat);
 
 #ifdef USE_KERBEROS5
   maj_stat = gss_test_oid_set_member (&min_stat, GSS_KRB5, oids, &n);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    kerberos5 supported => %d\n", n);
@@ -188,21 +186,21 @@ main (int argc, char *argv[])
   if (n)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 #endif
 
   maj_stat = gss_release_oid_set (&min_stat, &oids);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_release_oid_set() OK\n");
   else
-    fail ("gss_release_oid_set() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_release_oid_set() failed (%u,%u)\n", maj_stat, min_stat);
 
 #ifdef USE_KERBEROS5
   maj_stat = gss_inquire_names_for_mech (&min_stat, GSS_KRB5, &oids);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_inquire_names_for_mech() OK\n");
   else
-    fail ("gss_inquire_names_for_mech() failed (%d,%d)\n", maj_stat,
+    fail ("gss_inquire_names_for_mech() failed (%u,%u)\n", maj_stat,
 	  min_stat);
 
   /* Check if KRB5 supports PRINCIPAL_NAME name type */
@@ -211,7 +209,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    kerberos5 supports PRINCIPAL_NAME name type => %d\n", n);
@@ -219,7 +217,7 @@ main (int argc, char *argv[])
   if (n)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Check if KRB5 supports HOSTBASED NAME name type */
   maj_stat = gss_test_oid_set_member (&min_stat, GSS_C_NT_HOSTBASED_SERVICE,
@@ -227,7 +225,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    kerberos5 supports HOSTBASED_SERVICE name type => %d\n", n);
@@ -235,7 +233,7 @@ main (int argc, char *argv[])
   if (n)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Check if KRB5 supports ANONYMOUS name type */
   maj_stat = gss_test_oid_set_member (&min_stat, GSS_C_NT_ANONYMOUS,
@@ -243,7 +241,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    kerberos5 supports ANONYMOUS name type => %d\n", n);
@@ -251,13 +249,13 @@ main (int argc, char *argv[])
   if (!n)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   maj_stat = gss_release_oid_set (&min_stat, &oids);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_release_oid_set() OK\n");
   else
-    fail ("gss_release_oid_set() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_release_oid_set() failed (%u,%u)\n", maj_stat, min_stat);
 #endif
 
   /* Check name */
@@ -270,13 +268,13 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_import_name() OK\n");
   else
-    fail ("gss_import_name() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_import_name() failed (%u,%u)\n", maj_stat, min_stat);
 
   maj_stat = gss_display_name (&min_stat, service, &bufdesc2, NULL);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_display_name() OK\n");
   else
-    fail ("gss_display_name() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_display_name() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    display_name() => %d: %.*s\n", (int) bufdesc2.length,
@@ -286,7 +284,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_release_buffer() OK\n");
   else
-    fail ("gss_release_buffer() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_release_buffer() failed (%u,%u)\n", maj_stat, min_stat);
 
 #ifdef USE_KERBEROS5
   /* NB: "service" resused from previous test */
@@ -294,7 +292,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_inquire_mechs_for_name() OK\n");
   else
-    fail ("gss_inquire_mechs_for_name() failed (%d,%d)\n", maj_stat,
+    fail ("gss_inquire_mechs_for_name() failed (%u,%u)\n", maj_stat,
 	  min_stat);
 
   /* Check GSS_C_NT_HOSTBASED_SERVICE name type is supported by KRB5 */
@@ -302,7 +300,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    HOSTBASED_SERVICE supported by kerberos5 => %d\n", n);
@@ -310,7 +308,7 @@ main (int argc, char *argv[])
   if (n)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Dummy OID check */
   maj_stat = gss_test_oid_set_member (&min_stat, GSS_C_NT_ANONYMOUS,
@@ -318,7 +316,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    Dummy oid supported by kerberos5 => %d\n", n);
@@ -326,13 +324,13 @@ main (int argc, char *argv[])
   if (!n)
     success ("gss_test_oid_set_member() OK\n");
   else
-    fail ("gss_test_oid_set_member() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_test_oid_set_member() failed (%u,%u)\n", maj_stat, min_stat);
 
   maj_stat = gss_release_oid_set (&min_stat, &oids);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_release_oid_set() OK\n");
   else
-    fail ("gss_release_oid_set() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_release_oid_set() failed (%u,%u)\n", maj_stat, min_stat);
 #endif
 
   /* Release service allocated earlier. */
@@ -340,7 +338,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_release_name() OK\n");
   else
-    fail ("gss_release_name() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_release_name() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Check display_status */
   msgctx = 0;
@@ -349,7 +347,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_display_status() OK\n");
   else
-    fail ("gss_display_status() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_display_status() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("    Display status for GSS_S_COMPLETE => %*s\n",
@@ -359,7 +357,7 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_release_buffer() OK\n");
   else
-    fail ("gss_release_buffer() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_release_buffer() failed (%u,%u)\n", maj_stat, min_stat);
 
   /* Encapsulate. */
   bufdesc.value = (char *) "context token";
@@ -368,40 +366,40 @@ main (int argc, char *argv[])
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_encapsulate_token() OK\n");
   else
-    fail ("gss_encapsulate_token() failed (%d)\n", maj_stat);
+    fail ("gss_encapsulate_token() failed (%u)\n", maj_stat);
 
   maj_stat = gss_decapsulate_token (&bufdesc2, GSS_C_NT_ANONYMOUS, &bufdesc);
   if (maj_stat == GSS_S_DEFECTIVE_TOKEN)
     success ("gss_decapsulate_token(bad oid) OK\n");
   else
-    fail ("gss_decapsulate_token() failed (%d)\n", maj_stat);
+    fail ("gss_decapsulate_token() failed (%u)\n", maj_stat);
 
-  n = ((char *)bufdesc2.value)[3];
-  ((char *)bufdesc2.value)[3] = 42;
+  n = ((char *) bufdesc2.value)[3];
+  ((char *) bufdesc2.value)[3] = 42;
   maj_stat = gss_decapsulate_token (&bufdesc2, GSS_C_NT_USER_NAME, &bufdesc);
-  ((char *)bufdesc2.value)[3] = n;
+  ((char *) bufdesc2.value)[3] = n;
   if (maj_stat == GSS_S_DEFECTIVE_TOKEN)
     success ("gss_decapsulate_token(bad length) OK\n");
   else
-    fail ("gss_decapsulate_token() failed (%d)\n", maj_stat);
+    fail ("gss_decapsulate_token() failed (%u)\n", maj_stat);
 
   maj_stat = gss_decapsulate_token (&bufdesc2, GSS_C_NT_USER_NAME, &bufdesc);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_decapsulate_token() OK\n");
   else
-    fail ("gss_decapsulate_token() failed (%d)\n", maj_stat);
+    fail ("gss_decapsulate_token() failed (%u)\n", maj_stat);
 
   maj_stat = gss_release_buffer (&min_stat, &bufdesc);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_release_buffer() OK\n");
   else
-    fail ("gss_release_buffer() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_release_buffer() failed (%u,%u)\n", maj_stat, min_stat);
 
   maj_stat = gss_release_buffer (&min_stat, &bufdesc2);
   if (maj_stat == GSS_S_COMPLETE)
     success ("gss_release_buffer() OK\n");
   else
-    fail ("gss_release_buffer() failed (%d,%d)\n", maj_stat, min_stat);
+    fail ("gss_release_buffer() failed (%u,%u)\n", maj_stat, min_stat);
 
   if (debug)
     printf ("Basic self tests done with %d errors\n", error_count);
