@@ -1,22 +1,20 @@
 /* krb5context.c --- Kerberos 5 security context self tests.
- * Copyright (C) 2003-2014 Simon Josefsson
+ * Copyright (C) 2003-2022 Simon Josefsson
  *
- * This file is part of the Generic Security Service (GSS).
+ * This file is part of the GNU Generic Security Service Library.
  *
- * GSS is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ * This file is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published
+ * by the Free Software Foundation, either version 3 of the License,
+ * or (at your option) any later version.
  *
- * GSS is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
- * License for more details.
+ * This file is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GSS; if not, see http://www.gnu.org/licenses or write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth
- * Floor, Boston, MA 02110-1301, USA.
+ * along with this file.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -49,7 +47,7 @@ display_status_1 (const char *m, OM_uint32 code, int type)
       maj_stat = gss_display_status (&min_stat, code,
 				     type, GSS_C_NO_OID, &msg_ctx, &msg);
       if (GSS_ERROR (maj_stat))
-	printf ("GSS-API display_status failed on code %d type %d\n",
+	printf ("GSS-API display_status failed on code %u type %d\n",
 		code, type);
       else
 	{
@@ -185,7 +183,7 @@ main (int argc, char *argv[])
 	  if (ret_flags != (GSS_C_REPLAY_FLAG |
 			    GSS_C_CONF_FLAG |
 			    GSS_C_SEQUENCE_FLAG | GSS_C_PROT_READY_FLAG))
-	    fail ("loop 2 ret_flags failure (%d)\n", ret_flags);
+	    fail ("loop 2 ret_flags failure (%u)\n", ret_flags);
 	  if (maj_stat != GSS_S_COMPLETE)
 	    fail ("loop 1 init failure\n");
 	  break;
@@ -228,7 +226,7 @@ main (int argc, char *argv[])
 			    /* XXX GSS_C_REPLAY_FLAG |
 			       GSS_C_SEQUENCE_FLAG | */
 			    GSS_C_PROT_READY_FLAG))
-	    fail ("loop 0 accept flag failure (%d)\n", ret_flags);
+	    fail ("loop 0 accept flag failure (%u)\n", ret_flags);
 	  break;
 
 	case 1:
@@ -307,7 +305,7 @@ main (int argc, char *argv[])
 	  if (ret_flags != (GSS_C_MUTUAL_FLAG |
 			    GSS_C_REPLAY_FLAG |
 			    GSS_C_SEQUENCE_FLAG | GSS_C_PROT_READY_FLAG))
-	    fail ("loop 1 ret_flags failure (%d)\n", ret_flags);
+	    fail ("loop 1 ret_flags failure (%u)\n", ret_flags);
 	  break;
 
 	  /* No case 2. */
